$cbox-button-background-color: #fff !default;
$cbox-button-size: 40px !default;

@include declare-variables(
    cbox-button-background-color,
    cbox-button-size);

#cboxContent {
  > button {
    background-image: none;
    width: $cbox-button-size;
    height: $cbox-button-size;
    text-indent: 0;
    font-size: 0;
    @extend .fa-icon;
    &:before {
      font-size: $cbox-button-size / 2;
      margin-right: 0 !important;
    }
  }
}

#cboxLoadedContent {
  margin-bottom: 0;
}

#cboxPrevious {
  @extend .fa-chevron-left;
  background-color: $cbox-button-background-color;
}

#cboxNext {
  @extend .fa-chevron-right;
  background-color: $cbox-button-background-color;
}

#cboxClose {
  @extend .fa-times;
  width: 50px;
  text-indent: 0;
  font-size: 0;
  padding: 0;
  position: absolute;
  bottom: 0;
  right: 0;
  padding-bottom: 20px;
}

#cboxTitle {
  position: absolute;
  bottom: 0;
  background-color: rgba(255, 255, 255, .8);
  padding: 20px 65px 20px 95px;
  color: #000;
  text-align: left;
  box-sizing: border-box;
  font-weight: bold;

  // The colorbox title displays a white rectangle without any text
  // So do not render the title when the element is empty
  &:empty {
    display: none !important;
  }
}

#cboxCurrent {
  position: absolute;
  bottom: 0;
  width: 80px;
  text-align: center;
  color: #000;
  padding-bottom: 20px;
  letter-spacing: 4px;
  font-weight: bold;
}

/* Style mobile colorbox */
#cboxWrapper {
  #cboxTitle, #cboxCurrent {
    font-size: 15px;
    padding-top: 10px;
    padding-bottom: 10px;
    @include screen-small() {
      font-size: 20px;
      padding-top: 20px;
      padding-bottom: 20px;
    }
  }

  #cboxClose {
    padding-bottom: 10px;
    @include screen-small() {
      padding-bottom: 20px;
    }
  }
}
